#
# spec file for package talloc-man
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitearch:  %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{!?py3_soflags:  %global py3_soflags cpython-%{python3_version_nodots}m}
%if 0%{?suse_version} > 1310 || 0%{?fedora_version} > 20
%define with_python3 1
%else
%define with_python3 0
%endif
%define build_man 1

%if %{build_man}
Name:           talloc-man
BuildRequires:  doxygen
%else
Name:           talloc
BuildRequires:  autoconf
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt
BuildRequires:  pkg-config
BuildRequires:  python-devel
%if %{with_python3}
BuildRequires:  python3-devel
%endif
#!BuildIgnore:  python
%endif # build_man
Url:            http://talloc.samba.org/
Version:        2.1.10
Release:        lp150.1.4
Summary:        Samba talloc Library
License:        LGPL-3.0+
Group:          Development/Libraries/C and C++
Source:         http://download.samba.org/pub/talloc/talloc-%{version}.tar.gz
Source1:        http://download.samba.org/pub/talloc/talloc-%{version}.tar.asc
Source4:        baselibs.conf
Patch0:         talloc-python3.5-fix-soabi_name.patch
Source50:       talloc.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Talloc is a hierarchical, reference counted memory pool system with
destructors.

It is the core memory allocator used in Samba.

%if ! %{build_man}

%if 0%{?suse_version} > 0
%define libtalloc_name libtalloc2
%else
%define libtalloc_name libtalloc
%endif
%package -n %{libtalloc_name}
Summary:        Samba talloc library
Group:          System/Libraries
Provides:       bundled(libreplace)

%description -n %{libtalloc_name}
Talloc is a hierarchical, reference counted memory pool system with
destructors.

It is the core memory allocator used in Samba.

This package includes the talloc2 library.


%package -n libtalloc-devel
Summary:        Libraries and Header Files to Develop Programs with talloc2 Support
# Man pages are built in a 2nd spec file in order to break a build cycle with doxygen->cmake->krb5->libtalloc
Group:          Development/Libraries/C and C++
%if 0%{?suse_version} > 1030
Recommends:     %{name}-man
%endif
Requires:       %{libtalloc_name} = %{version}
Requires:       pkg-config

%description -n libtalloc-devel
Talloc is a hierarchical, reference counted memory pool system with
destructors.

It is the core memory allocator used in Samba.

Libraries and Header Files to Develop Programs with talloc2 Support.


%package -n python-talloc
Summary:        Python bindings for the Talloc library
Group:          Development/Libraries/Python
Requires:       %{libtalloc_name} = %{version}
Provides:       pytalloc = %{version}
Obsoletes:      pytalloc < %{version}

%description -n python-talloc
This package contains the Python bindings for the Talloc library.


%package -n python-talloc-devel
Summary:        Developer tools for the Talloc library
Group:          Development/Libraries/Python
Requires:       pkg-config
Requires:       python-talloc = %{version}
Provides:       pytalloc-devel = %{version}
Obsoletes:      pytalloc-devel < %{version}
Conflicts:      python3-talloc-devel

%description -n python-talloc-devel
Libraries and Header Files to Develop Programs with python-talloc Support


%if %{with_python3}
%package -n python3-talloc
Summary:        Python3 bindings for the Talloc library
Group:          Development/Libraries/Python
Requires:       %{libtalloc_name} = %{version}

%description -n python3-talloc
This package contains the Python3 bindings for the Talloc library.


%package -n python3-talloc-devel
Summary:        Developer tools for the Talloc library
Group:          Development/Libraries/Python
Requires:       pkg-config
Requires:       python3-talloc = %{version}
Conflicts:      python-talloc-devel

%description -n python3-talloc-devel
Libraries and Header Files to Develop Programs with python3-talloc Support
%endif

%endif # ! build_man

%prep
%setup -n talloc-%{version} -q
%patch0 -p1

%build
%if ! %{build_man}
export CFLAGS="%{optflags} -D_GNU_SOURCE -D_LARGEFILE64_SOURCE -DIDMAP_RID_SUPPORT_TRUSTED_DOMAINS"
CONFIGURE_OPTIONS="\
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--disable-rpath \
	--disable-rpath-install \
	--disable-silent-rules \
	--bundled-libraries=NONE \
	--builtin-libraries=replace \
%if %{with_python3}
	--extra-python=/usr/bin/python3 \
%endif
"
./configure ${CONFIGURE_OPTIONS}
make %{?_smp_mflags} \
	all

%else

doxygen doxy.config

%endif # ! build_man

%if ! %{build_man}
%check
%if 0%{?suse_version} != 1110 || "%{_build_arch}" == x86_64
%if "%{qemu_user_space_build}" == "1"
echo "skipping test on qemu userspace build due to AT_RANDOM not changing"
%else # qemu_user_space_build == 1
mkdir lib/talloc
ln test_magic_differs* lib/talloc/
LD_LIBRARY_PATH=bin/shared make test
%endif # qemu_user_space_build == 1
%endif # suse_version != 1110; fails for i586 and ppc64
%endif # ! build_man

%install
%if ! %{build_man}
%make_install
rm -r "%{buildroot}/%{_mandir}"

%else

# Install API documentation
mkdir -p "%{buildroot}/%{_mandir}"
cp -a doc/man/* "%{buildroot}/%{_mandir}/"

%endif  # ! build_man

%if ! %{build_man}
%post -n %{libtalloc_name} -p /sbin/ldconfig

%postun -n %{libtalloc_name} -p /sbin/ldconfig

%post -n python-talloc -p /sbin/ldconfig

%postun -n python-talloc -p /sbin/ldconfig

%post -n python3-talloc -p /sbin/ldconfig

%postun -n python3-talloc -p /sbin/ldconfig

%files -n %{libtalloc_name}
%defattr(-,root,root)
%{_libdir}/libtalloc.so.*

%files -n libtalloc-devel
%defattr(-,root,root)
%{_includedir}/talloc.h
%{_libdir}/libtalloc.so
%{_libdir}/pkgconfig/talloc.pc

%files -n python-talloc
%defattr(-,root,root)
%{_libdir}/libpytalloc-util.so.*
%{python_sitearch}/talloc.so

%files -n python-talloc-devel
%defattr(-,root,root)
%{_includedir}/pytalloc.h
%{_libdir}/pkgconfig/pytalloc-util.pc
%{_libdir}/libpytalloc-util.so

%if %{with_python3}
%files -n python3-talloc
%defattr(-,root,root)
%{_libdir}/libpytalloc-util.%{py3_soflags}.so.*
%{python3_sitearch}/talloc.%{py3_soflags}.so

%files -n python3-talloc-devel
%defattr(-,root,root)
%{_includedir}/pytalloc.h
%{_libdir}/pkgconfig/pytalloc-util.pc
%{_libdir}/pkgconfig/pytalloc-util.%{py3_soflags}.pc
%{_libdir}/libpytalloc-util.%{py3_soflags}.so
%endif

%else

%files
%defattr(-,root,root)
%{_mandir}/man3/libtalloc*.3.*
%{_mandir}/man3/talloc*.3.*

%endif # ! build_man

%changelog
* Mon Oct  2 2017 jengelh@inai.de
- Remove %%if guards for blocks that do not affect the build result.
  Fix RPM groups and summaries. Drop very old SUSE support.
  Replace old RPM macros by new constructs.
* Wed Jul 26 2017 scabrero@suse.com
- Update to version 2.1.10
  + build, documentation and python3 improvements
  + delete sle11-remove-unknown-compiler-options.patch, supported
    options are checked for in upstream code
* Thu Mar 23 2017 jmcdonough@suse.com
- sle11-remove-unknown-compiler-options.patch: build SLE11 and earlier
  without -Wno-format-length.
* Wed Mar 22 2017 jmcdonough@suse.com
- Update to version 2.1.9; (bsc#1032915).
  + fix some coverity defects
  + fix TALLOC_VERSION_MINOR and talloc_version_minor()
  + add new tests
  + add pytalloc_get_type()
  + add pytalloc_GenericObject_{steal,reference}[_ex]()
* Wed Sep 14 2016 jmcdonough@suse.com
- Update to version 2.1.8.
  + performance improvements
  + Fix memory leak when destructors reparent children; (bso#11901).
* Tue Mar 15 2016 lmuelle@suse.com
- Update to 2.1.6; (bsc#954658).
  + pytalloc: Add new BaseObject
  + pytalloc: add a _pytalloc_get_type() helper function and generate
    PyExc_TypeError on mismatch
  + talloc: add _pytalloc_get_ptr/_pytalloc_get_mem_ctx helper functions
  + Improve testsuite by avoiding path issues
  + Only set public headers field when installing as a public library
  + Fix a documentation typo
* Mon Mar  7 2016 toddrme2178@gmail.com
- Add talloc-python3.5-fix-soabi_name.patch: Do not change x86_64 to
  x86-64 when building with python 3.5.
* Sun Feb 21 2016 lmuelle@suse.com
- Avoid a file collision for non SUSE build targets; (bsc#966174).
* Fri Feb 12 2016 lmuelle@suse.com
- Provide python-talloc and python-talloc-devel; (bsc#966523).
* Wed Nov 11 2015 lmuelle@suse.com
- Update to 2.1.5; (bsc#954658).
  + Minor build fixes
* Sun Nov  8 2015 lmuelle@suse.com
- Point LD_LIBRARY_PATH to the just-built libraries while calling make test.
- Create a 2nd talloc-man spec-file to avoid a build cycle.
- Recommend to install talloc-man from libtalloc-devel.
* Fri Oct 30 2015 lmuelle@suse.com
- Add doxygen at build time to add the development documentation.
- Disable rpath-install and silent-rules while configure.
* Sat Oct 24 2015 lmuelle@suse.com
- Add python3-talloc and python3-talloc-devel; (bsc#951911).
* Thu Oct 22 2015 lmuelle@suse.com
- Rename pytalloc to python-talloc.
* Thu Oct 22 2015 lmuelle@suse.com
- Update to 2.1.4; (bsc#951660).
  + Test that talloc magic differs between processes.
  + Increment minor version due to added talloc_test_get_magic.
  + Provide tests access to talloc_magic.
  + Test magic protection measures.
* Mon Sep  7 2015 lmuelle@suse.com
- Update the Samba Library Distribution Key file 'talloc.keyring';
  (bso#945116).
* Wed Jul 22 2015 lmuelle@suse.com
- Update to 2.1.3; (bsc#939051).
  + improved python3 bindings
  + documentation fixes regarding talloc_reference() and talloc_unlink()
* Thu Apr 16 2015 lmuelle@suse.com
- Update to 2.1.2.
  + Fix memory leak in SMB2 notify handling; (bso#11144).
  + fix _talloc_total_limit_size prototype
  + build: improve detection of srcdir
* Thu Nov  6 2014 lmuelle@suse.com
- Use the upstream tar ball, as signature verification is now able to handle
  compressed archives.
* Fri May 23 2014 lmuelle@suse.com
- Require pkg-config from the devel packages.
* Thu May 22 2014 lmuelle@suse.com
- Update to 2.1.1.
  + documentation updates
  + a fix for pytalloc-util.pc
  + performance improvements here and there
  + fixed compiler warnings
* Tue May 20 2014 dmueller@suse.com
- Remove dependency on doxygen. Doxygen is only used for generating
  the html documentation, but the html documentation was not
  actually packaged, so there is no point in running it.
* Wed Apr 23 2014 dmueller@suse.com
- Remove dependency on gpg-offline to reduce rebuild times; signature checking
  is implemented already in the source validator.
* Fri Dec  6 2013 lmuelle@suse.com
- Update to 2.1.0.
  + Add talloc_pooled_object and test it
  + Allow nested pools
  + Add a separate pool size
  + Put pool-specific data before the chunk
  + Introduce __talloc_with_prefix
  + Decouple the dual use of chunk->pool
  + Only provide the --enable-talloc-compat1 in standalone build
  + Simplify _talloc_free_poolmem a bit
* Fri Dec  6 2013 lmuelle@suse.com
- Verify source tar ball gpg signature.
* Thu Aug 29 2013 lmuelle@suse.com
- PreReq /sbin/ldconfig from pytalloc.
* Wed Aug 28 2013 lmuelle@suse.com
- Add pytalloc to baselibs.conf.
* Mon Jul 22 2013 lmuelle@suse.com
- BuildIgnore python for post-11.0 systems only.
- Package the talloc man page only on post-11.0 systems.
* Sun Jul  7 2013 coolo@suse.com
- BuildIgnore python to avoid build cycle
* Sun Dec  2 2012 lmuelle@suse.com
- Update to 2.0.8.
  + Convert error cecking macros into fns
  + don't allow a talloc_pool inside a talloc_pool.
  + use a struct for pool headers.
  + remove unused variables
  + Update doxygen config.
  + Slightly simplify talloc_unlink
  + Only check for pkg-config file when checking for system talloc.
  + fix a comment typo
  + simplifiy the logic to build talloc_testsuite in the standalone build
* Thu Jun 28 2012 lmuelle@suse.com
- Disable rpath while configure.
* Tue Jun 12 2012 lmuelle@suse.com
- Add missing group field to the library subpackage.
* Sun Jun  3 2012 lmuelle@suse.com
- Define library name and use it instead of libtalloc2.
* Sat Jun  2 2012 lmuelle@suse.com
- Rename package to talloc and add an independent libtalloc2 subpackage.
- Enhance and polish the package descriptions and summaries.
* Thu May 31 2012 lmuelle@suse.com
- BuildRequire pkg-config for post-10.2 systems and else pkgconfig.
* Thu May 31 2012 lmuelle@suse.com
- Rename libtalloc2-devel to libtalloc-devel.
* Wed May 30 2012 lmuelle@suse.com
- Define python_sitearch if undefined.
* Wed May 30 2012 lmuelle@suse.com
- Remove superfluous AutoReqProv on line.
* Wed May 16 2012 lmuelle@suse.com
- Require libtalloc2 from libtalloc2-devel.
* Wed May 16 2012 lmuelle@suse.com
- Cleanup BuildRequires and spec file in general.
- Add new pytalloc and pytalloc-devel sub packages.
* Wed Sep  7 2011 lars@samba.org
- Initial independent libtalloc2 package.
